<?php
/**
 * Utilisations de pipelines par Login Hash
 *
 * @plugin     Login Hash
 * @copyright  2019
 * @author     Matthieu Marcillaud
 * @licence    GNU/GPL
 * @package    SPIP\Loginhash\Pipelines
 */

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}


/**
 * Définir un login (hash) systématiquement pour les nouveaux auteurs
 */
function loginhash_pre_insertion($flux) {
	if (
		$flux['args']['table'] === 'spip_auteurs'
		and empty($flux['data']['login'])
	) {
		$flux['data']['login'] = loginhash_generer_hash();
	}
	return $flux;
}

function loginhash_formulaire_fond($flux) {
	# Ajouter un bouton pour reset le login
	if ($flux['args']['form'] === 'editer_auteur') {
		$auth_methode = $flux['args']['contexte']['source'] ?? '';
		include_spip('inc/auth');
		if (
			$auth_methode
			and auth_autoriser_modifier_login($auth_methode)
			and autoriser('modifier', 'auteur', $flux['args']['contexte']['id_auteur'], null, array('email' => true))
		) {
			$reg = "#<input (?:[^>]+) id='new_login' (?:[^>]+) />#i";
			if (preg_match($reg, $flux['data'], $m)) {
				$input = $m[0];
				$button =
					'<input type="submit" class="over offscreen" name="submit" value="submit" />'
					. '<button type="submit" class="submit reset_login" name="reset_login" value="1">'
					. _T('loginhash:bouton_reset_login')
					. '</button>';
				$flux['data'] = str_replace($input, $input . $button, $flux['data']);
			}
		}
	}
	return $flux;
}

function loginhash_formulaire_verifier($flux) {
	/* Générer un login */
	if (
		$flux['args']['form'] === 'editer_auteur'
		and $id_auteur = intval($flux['args']['args'][0])
		and _request('reset_login')
		and autoriser('modifier', 'auteur', $id_auteur, null, array('email' => true))
	) {
		$auth_methode = sql_getfetsel('source', 'spip_auteurs', 'id_auteur=' . intval($id_auteur));
		$auth_methode = ($auth_methode ? $auth_methode : 'spip');
		$new_login = loginhash_generer_hash();
		set_request('new_login', $new_login);
		if ($err = auth_verifier_login($auth_methode, $new_login, $id_auteur)) {
			$flux['data']['new_login'] = $err;
			$flux['data']['message_erreur'] .= $err;
		}
	}
	return $flux;
}